﻿local function FindIcon(ary, str)
	table.wipe(ary);
	ary[1] = "INV_MISC_QUESTIONMARK";

	local num = tonumber(str);
	if texnum ~= nil then
		return ArtTexturePaths[num];
	end

	for i, path in pairs(ArtTexturePaths) do
		path = string.lower(path);
		if string.find(path, str)then
			tinsert(ary, i);
		end
	end
end

local function Crop()
	local ary = {};
	for i, path in pairs(ArtTexturePaths) do
		if string.find(path, "/Icons/") ~= nil then
			ary[i] = gsub(path, "Interface/Icons/", "");
		end
	end
	table.wipe(ArtTexturePaths);
	for i, v in pairs(ary) do
		ArtTexturePaths[i] = v;
	end
end

local addon = CreateFrame("Frame", "SearchForIcons", nil);
function addon:Initialize()
	if self.onload then
		return;
	end
	Crop();

	local editbox = CreateFrame("EditBox", "SearchForIconsEditbox", addon, "SearchForIconsEditboxTemplate");
	local textEditbox = addon:CreateFontString("SearchForIconsEditboxText", "BORDER", "GameFontHighlightSmall");
	local textSearch = addon:CreateFontString("SearchForIconsSearchText", "BORDER", "GameFontHighlightSmall");

	textEditbox:SetText(GetText("KBASE_DEFAULT_SEARCH_TEXT"));
	textEditbox:SetPoint("TOPRIGHT", addon, "TOPRIGHT", -24, -21);

	textSearch:SetText(GetText("KBASE_SEARCH_RESULTS"));
	textSearch:SetPoint("TOPRIGHT", addon, "TOPRIGHT", -42, -69);
	textSearch:Hide();
	
	editbox.prev = "";
	editbox:SetScript("OnEscapePressed", function(self)
		self:ClearFocus();
		self.prev = "";
		self:SetText("");
		if addon.searched then
			addon:Refresh();
			addon:Update();
		end
	end);
	editbox:SetScript("OnEnterPressed", function(self)

	end);
	editbox:SetScript("OnTextChanged", function(self, ...)
		if self:GetText() == self.prev then
			return;
		end
		self.prev = self:GetText();
		table.wipe(addon.ary);
		addon.searched = true;
		if self:GetText() == "" then
			addon.textSearch:Hide();
			addon:Refresh();
			--table.wipe(addon.ary);
			--addon.ary[1] = "INV_MISC_QUESTIONMARK";
		else
			addon.textSearch:Show();
			FindIcon(addon.ary, self:GetText());	
		end
		addon:Update();
	end);
	
	self.editbox = editbox;
	self.textEditbox = textEditbox;
	self.textSearch = textSearch;
	self.onload = true;
end

hooksecurefunc("GetMacroIcons", function(ICON_FILENAMES) 
	addon.ary = ICON_FILENAMES;

	local parent;
	if GuildBankPopupFrame and GuildBankPopupFrame:IsShown() then
		parent = GuildBankPopupFrame;
	elseif MacroPopupFrame and MacroPopupFrame:IsShown() then
		parent = MacroPopupFrame;
	else
		parent = GearManagerDialogPopup;
	end

	addon:Initialize();
	addon:ClearAllPoints();
	addon:SetParent(parent);
	addon:SetAllPoints();
	addon:Show();
	addon.editbox.prev = "";
	addon.editbox:SetText("");
	addon.textSearch:Hide();
	
	local numSpecs = GetNumSpecializations();
	for i = numSpecs, 1, -1 do
		local specId, specName, specExp, specTex, specJob = GetSpecializationInfo(i);
		if specTex then
			tinsert(addon.ary, 2, specTex);
		end
	end

	if addon.backup then
		table.wipe(addon.backup);
	else
		addon.backup = {};
	end

	for i, path in pairs(ICON_FILENAMES) do
		addon.backup[i] = path;
	end
end);

function addon:Update()
	if GuildBankPopupFrame and GuildBankPopupFrame:IsShown() then
		GuildBankPopupFrame_Update(GetCurrentGuildBankTab());
		GuildBankPopupScrollFrame:SetVerticalScroll(0);
	elseif MacroFrame and MacroFrame:IsShown() then
		MacroPopupFrame_Update();
		MacroPopupScrollFrame:SetVerticalScroll(0);
	else
		GearManagerDialogPopup_Update();
		GearManagerDialogPopupScrollFrame:SetVerticalScroll(0);
	end
end

function addon:Refresh()
	table.wipe(addon.ary);
	for i, path in pairs(addon.backup) do
		addon.ary[i] = path;
	end
	if GuildBankPopupFrame and GuildBankPopupFrame:IsShown() then
		GuildBankPopupScrollFrame:SetVerticalScroll(0);
	elseif MacroFrame and MacroFrame:IsShown() then
		MacroPopupScrollFrame:SetVerticalScroll(0);
	else
		GearManagerDialogPopupScrollFrame:SetVerticalScroll(0);
	end
	addon.textSearch:Hide();
end